@@ -61,6 +61,7 @@ for x in PyKCS11.LowLevel.__dict__.keys():
             eval(x[:3])[x] = eval(x)  # => CKM['CKM_RSA_PKCS'] = CKM_RSA_PKCS
 
 # special CKR[] values
+CKR[-4] = "C_GetFunctionList() not found"
 CKR[-3] = "Unknown format"
 CKR[-2] = "Unkown PKCS#11 type"
 CKR[-1] = "Load"
@@ -105,7 +106,7 @@ class ckbytelist(PyKCS11.LowLevel.ckbytelist):
             for c in range(len(data)):
                 self.append(data[c])
         else:
-            raise PyKCS11.PyKCS11Error(-3, text=type(data))
+            raise PyKCS11.PyKCS11Error(-3, text=str(type(data)))
 
     def __repr__(self):
         """
@@ -479,8 +480,8 @@ class PyKCS11Lib(object):
             if pkcs11dll_filename is None:
                 raise PyKCS11Error(-1, "No PKCS11 library specified (set PYKCS11LIB env variable)")
         rv = self.lib.Load(pkcs11dll_filename)
-        if rv == 0:
-            raise PyKCS11Error(-1, pkcs11dll_filename)
+        if rv != CKR_OK:
+            raise PyKCS11Error(rv, pkcs11dll_filename)
 
     def initToken(self, slot, pin, label):
         """
@@ -739,6 +740,36 @@ MechanismECGENERATEKEYPAIR = Mechanism(CKM_EC_KEY_PAIR_GEN, None)
 MechanismAESGENERATEKEY = Mechanism(CKM_AES_KEY_GEN, None)
 
 
+class AES_GCM_Mechanism(object):
+    """CKM_AES_GCM warpping mechanism"""
+
+    def __init__(self, iv, aad, tagBits):
+        """
+        :param iv: initialization vector
+        :param aad: additional authentication data
+        :param tagBits: length of authentication tag in bits
+        """
+        self._param = PyKCS11.LowLevel.CK_GCM_PARAMS()
+
+        self._source_iv = ckbytelist(iv)
+        self._param.pIv = self._source_iv
+        self._param.ulIvLen = len(self._source_iv)
+
+        self._source_aad = ckbytelist(aad)
+        self._param.pAAD = self._source_aad
+        self._param.ulAADLen = len(self._source_aad)
+
+        self._param.ulTagBits = tagBits
+
+        self._mech = PyKCS11.LowLevel.CK_MECHANISM()
+        self._mech.mechanism = CKM_AES_GCM
+        self._mech.pParameter = self._param
+        self._mech.ulParameterLen = PyKCS11.LowLevel.CK_GCM_PARAMS_LENGTH
+
+    def to_native(self):
+        return self._mech
+
+
 class RSAOAEPMechanism(object):
     """RSA OAEP Wrapping mechanism"""
 
